@@ -97,14 +97,6 @@ impl VisitMut for ConstPropagation<'_> {
         n.visit_mut_children_with(&mut v);
     }
 
-    fn visit_mut_member_expr(&mut self, e: &mut MemberExpr) {
-        e.obj.visit_mut_with(self);
-
-        if let MemberProp::Computed(c) = &mut e.prop {
-            c.visit_mut_with(self);
-        }
-    }
-
     fn visit_mut_prop(&mut self, p: &mut Prop) {
         p.visit_mut_children_with(self);
 
@@ -118,12 +110,6 @@ impl VisitMut for ConstPropagation<'_> {
         }
     }
 
-    fn visit_mut_super_prop_expr(&mut self, e: &mut SuperPropExpr) {
-        if let SuperProp::Computed(c) = &mut e.prop {
-            c.visit_mut_with(self);
-        }
-    }
-
     fn visit_mut_var_decl(&mut self, var: &mut VarDecl) {
         var.decls.visit_mut_with(self);
 
